@@ -17,10 +17,10 @@ use Encode 'encode', 'decode';
 
 use Carp 'confess';
 
-our $VERSION = '0.0369';
+our $VERSION = '0.0370';
 
-our $ENV;
-our $BUILDER;
+my $SPVM_ENV;
+my $BUILDER;
 
 require XSLoader;
 XSLoader::load('SPVM', $VERSION);
@@ -58,42 +58,42 @@ CHECK {
     }
     
     # Set env
-    $SPVM::ENV = $BUILDER->{env};
+    $SPVM_ENV = $BUILDER->{env};
   }
 }
 
-sub new_object_array { SPVM::PerlAPI::new_object_array($SPVM::ENV, @_) }
-sub new_value_t_array { SPVM::PerlAPI::new_value_t_array($SPVM::ENV, @_) }
-sub new_object { SPVM::PerlAPI::new_object($SPVM::ENV, @_) }
+sub new_object_array { SPVM::PerlAPI::new_object_array($SPVM_ENV, @_) }
+sub new_value_t_array { SPVM::PerlAPI::new_value_t_array($SPVM_ENV, @_) }
+sub new_object { SPVM::PerlAPI::new_object($SPVM_ENV, @_) }
 
-sub new_byte_array_len { SPVM::PerlAPI::new_byte_array_len($SPVM::ENV, @_) }
-sub new_short_array_len { SPVM::PerlAPI::new_short_array_len($SPVM::ENV, @_) }
-sub new_int_array_len { SPVM::PerlAPI::new_int_array_len($SPVM::ENV, @_) }
-sub new_long_array_len { SPVM::PerlAPI::new_long_array_len($SPVM::ENV, @_) }
-sub new_float_array_len { SPVM::PerlAPI::new_float_array_len($SPVM::ENV, @_) }
-sub new_double_array_len { SPVM::PerlAPI::new_double_array_len($SPVM::ENV, @_) }
-sub new_object_array_len { SPVM::PerlAPI::new_object_array_len($SPVM::ENV, @_) }
-sub new_multi_array_len { SPVM::PerlAPI::new_multi_array_len($SPVM::ENV, @_) }
-sub new_value_t_array_len { SPVM::PerlAPI::new_value_t_array_len($SPVM::ENV, @_) }
-sub set_exception_undef { SPVM::PerlAPI::set_exception_undef($SPVM::ENV, @_) }
-sub get_memory_blocks_count { SPVM::PerlAPI::get_memory_blocks_count($SPVM::ENV, @_) }
-sub call_sub { SPVM::PerlAPI::call_sub($SPVM::ENV, @_) }
+sub new_byte_array_len { SPVM::PerlAPI::new_byte_array_len($SPVM_ENV, @_) }
+sub new_short_array_len { SPVM::PerlAPI::new_short_array_len($SPVM_ENV, @_) }
+sub new_int_array_len { SPVM::PerlAPI::new_int_array_len($SPVM_ENV, @_) }
+sub new_long_array_len { SPVM::PerlAPI::new_long_array_len($SPVM_ENV, @_) }
+sub new_float_array_len { SPVM::PerlAPI::new_float_array_len($SPVM_ENV, @_) }
+sub new_double_array_len { SPVM::PerlAPI::new_double_array_len($SPVM_ENV, @_) }
+sub new_object_array_len { SPVM::PerlAPI::new_object_array_len($SPVM_ENV, @_) }
+sub new_multi_array_len { SPVM::PerlAPI::new_multi_array_len($SPVM_ENV, @_) }
+sub new_value_t_array_len { SPVM::PerlAPI::new_value_t_array_len($SPVM_ENV, @_) }
+sub set_exception_undef { SPVM::PerlAPI::set_exception_undef($SPVM_ENV, @_) }
+sub get_memory_blocks_count { SPVM::PerlAPI::get_memory_blocks_count($SPVM_ENV, @_) }
+sub call_sub { SPVM::PerlAPI::call_sub($SPVM_ENV, @_) }
 
-sub new_byte_array { SPVM::PerlAPI::new_byte_array($SPVM::ENV, @_) }
-sub new_byte_array_string { SPVM::PerlAPI::new_byte_array_string($SPVM::ENV, @_) }
-sub new_short_array { SPVM::PerlAPI::new_short_array($SPVM::ENV, @_) }
-sub new_int_array { SPVM::PerlAPI::new_int_array($SPVM::ENV, @_) }
-sub new_long_array { SPVM::PerlAPI::new_long_array($SPVM::ENV, @_) }
-sub new_float_array { SPVM::PerlAPI::new_float_array($SPVM::ENV, @_) }
-sub new_double_array { SPVM::PerlAPI::new_double_array($SPVM::ENV, @_) }
+sub new_byte_array { SPVM::PerlAPI::new_byte_array($SPVM_ENV, @_) }
+sub new_byte_array_string { SPVM::PerlAPI::new_byte_array_string($SPVM_ENV, @_) }
+sub new_short_array { SPVM::PerlAPI::new_short_array($SPVM_ENV, @_) }
+sub new_int_array { SPVM::PerlAPI::new_int_array($SPVM_ENV, @_) }
+sub new_long_array { SPVM::PerlAPI::new_long_array($SPVM_ENV, @_) }
+sub new_float_array { SPVM::PerlAPI::new_float_array($SPVM_ENV, @_) }
+sub new_double_array { SPVM::PerlAPI::new_double_array($SPVM_ENV, @_) }
 
-sub set_array_elements { SPVM::PerlAPI::set_array_elements($SPVM::ENV, @_) }
-sub set_array_elements_bin { SPVM::PerlAPI::set_array_elements_bin($SPVM::ENV, @_) }
-sub set_array_element { SPVM::PerlAPI::set_array_element($SPVM::ENV, @_) }
-sub get_array_element { SPVM::PerlAPI::get_array_element($SPVM::ENV, @_) }
-sub get_array_elements { SPVM::PerlAPI::get_array_elements($SPVM::ENV, @_) }
-sub get_array_elements_bin { SPVM::PerlAPI::get_array_elements_bin($SPVM::ENV, @_) }
-sub get_array_elements_string { SPVM::PerlAPI::get_array_elements_string($SPVM::ENV, @_) }
+sub set_array_elements { SPVM::PerlAPI::set_array_elements($SPVM_ENV, @_) }
+sub set_array_elements_bin { SPVM::PerlAPI::set_array_elements_bin($SPVM_ENV, @_) }
+sub set_array_element { SPVM::PerlAPI::set_array_element($SPVM_ENV, @_) }
+sub get_array_element { SPVM::PerlAPI::get_array_element($SPVM_ENV, @_) }
+sub get_array_elements { SPVM::PerlAPI::get_array_elements($SPVM_ENV, @_) }
+sub get_array_elements_bin { SPVM::PerlAPI::get_array_elements_bin($SPVM_ENV, @_) }
+sub get_array_elements_string { SPVM::PerlAPI::get_array_elements_string($SPVM_ENV, @_) }
 
 1;
 
